/*
 *	aegis - project change supervisor
 *	Copyright (C) 1997, 1999, 2002-2004 Peter Miller;
 *	All rights reserved.
 *
 *	This program is free software; you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License as published by
 *	the Free Software Foundation; either version 2 of the License, or
 *	(at your option) any later version.
 *
 *	This program is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU General Public License for more details.
 *
 *	You should have received a copy of the GNU General Public License
 *	along with this program; if not, write to the Free Software
 *	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
 *
 * MANIFEST: interface definition for common/libdir.c
 */

#ifndef COMMON_LIBDIR_H
#define COMMON_LIBDIR_H

/** \addtogroup Configured
  * \brief Retrieve configure time values
  * \ingroup Common
  * @{
  */
const char *configured_prefix(void);
const char *configured_bindir(void);
const char *configured_comdir(void);
const char *configured_datadir(void);
const char *configured_libdir(void);
const char *configured_nlsdir(void);
const char *configured_mandir(void);
int configured_aegis_uid(void);
int configured_aegis_gid(void);
const char *configured_exeext(void);
const char *configured_sysconfdir(void);

/** @} */
#endif /* COMMON_LIBDIR_H */
